==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_nap.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=nap
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_message_commentaire' => 'Nu messaggio, na crosa?',
	'forum_acces_refuse' => 'Nun putite cchiú trasí ’int’a chisti forum.',
	'forum_attention_dix_caracteres' => '<b>Tenite mente!</b> ’o messaggio d’’o vuosto ha dda tené ammeno diece carattere.',
	'forum_attention_trois_caracteres' => '<b>Tenite mente!</b> ’o título ha dda tené ammeno tre carattere.',
	'forum_attention_trop_caracteres' => '<b>Tenite mente!</b> ’o messaggio è troppo luongo (@compte@ carattere): pe vve puté allegistrà nun ha dda passà ’e @max@ carattere.', # MODIF
	'forum_avez_selectionne' => 'Avite scèveto:',
	'forum_cliquer_retour' => 'Spremmite <a href=\\\'@retour_forum@\\\'>ccà</a> pe jí nnanze.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Chistu forum è moderato a priori: ’o cuntributo d’’o vuosto sarrà on line adoppo ca n’ammenestratore d’’o sito ll’appruvarrà.', # MODIF
	'forum_lien_hyper' => '<b>Jonta ipertestuale</b> (opzionale)', # MODIF
	'forum_message_definitif' => 'Messaggio deffenetivo: mannatelo ô sito',
	'forum_message_trop_long' => '’O messaggio d’’o vuosto è troppo luongo. Ha dda tené nu massimo ’e 20000 carattere.', # MODIF
	'forum_ne_repondez_pas' => 'Nun responnere a chistu messaggio e-mail, rispunne ncopp’ô forum ô nnerizzo innicato ccà: ', # MODIF
	'forum_page_url' => '(Si ’o messaggio d’’o vuosto è referuto a n’artículo pubbrecato ncopp’â Web, o a na pàggena ca tene cchiú nfromma, putite innicà ccà ’o título d’’a pàggina e ’o nnerizzo URL.)',
	'forum_poste_par' => 'Messaggio mannato ’a @parauteur@ ô funno ’e ll’artículo   « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Chi site?</b> (opzionale)', # MODIF
	'forum_texte' => 'Testo d’’o messaggio:', # MODIF
	'forum_titre' => 'Título:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Abbalurate â scèveta',
	'forum_voir_avant' => 'Vedite ’o messaggio primma d’’o mannà', # MODIF
	'forum_votre_email' => 'Nnerizzo ’e posta elettrònica:', # MODIF
	'forum_votre_nom' => 'Nomme (o scagnanomme/pseudonimo):', # MODIF
	'forum_vous_enregistrer' => 'Pe ppartecipà ô forum, v’avite allegistrà primma. Si l’avite fatto già, scrivite ccà ll’ID d’’a vuosta. Si nun l’avite fatto ancora, v’avite ',
	'forum_vous_inscrire' => 'nscrivere primma.',

	// I
	'icone_suivi_forums' => 'Ammenestrazzione d’’e forum',
	'icone_supprimer_message' => 'Canciella ô messaggio',
	'icone_valider_message' => 'Appruvate ô messaggio',
	'info_activer_forum_public' => '<i>Per attivare i forum pubblici, scegli il tipo
di moderazione predefinito:</i>', # MODIF
	'info_option_email' => 'Quando un visitatore del sito inserisce un nuovo messaggio nel forum
associato a un articolo, gli autori di quest’ultimo possono essere
avvertiti via email. Desideri utilizzare quest’opzione?', # MODIF

	// L
	'lien_reponse_site_reference' => 'Risposta al sito repertoriato:', # MODIF

	// O
	'onglet_messages_internes' => 'Messagge ’e dint’ô sito',
	'onglet_messages_publics' => 'Messagge púbbreche',
	'onglet_messages_vide' => 'Messagge vacante',

	// T
	'titre_forum' => 'Forum'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_nap.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=nap
// ** ne pas modifier le fichier **

return [

	// F
	'form_pet_message_commentaire' => 'Nu messaggio, na crosa?',
	'forum_acces_refuse' => 'Nun putite cchiú trasí ’int’a chisti forum.',
	'forum_attention_dix_caracteres' => '<b>Tenite mente!</b> ’o messaggio d’’o vuosto ha dda tené ammeno diece carattere.',
	'forum_attention_trois_caracteres' => '<b>Tenite mente!</b> ’o título ha dda tené ammeno tre carattere.',
	'forum_attention_trop_caracteres' => '<b>Tenite mente!</b> ’o messaggio è troppo luongo (@compte@ carattere): pe vve puté allegistrà nun ha dda passà ’e @max@ carattere.', # MODIF
	'forum_avez_selectionne' => 'Avite scèveto:',
	'forum_cliquer_retour' => 'Spremmite <a href=\\\'@retour_forum@\\\'>ccà</a> pe jí nnanze.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Chistu forum è moderato a priori: ’o cuntributo d’’o vuosto sarrà on line adoppo ca n’ammenestratore d’’o sito ll’appruvarrà.', # MODIF
	'forum_lien_hyper' => '<b>Jonta ipertestuale</b> (opzionale)', # MODIF
	'forum_message_definitif' => 'Messaggio deffenetivo: mannatelo ô sito',
	'forum_message_trop_long' => '’O messaggio d’’o vuosto è troppo luongo. Ha dda tené nu massimo ’e 20000 carattere.', # MODIF
	'forum_ne_repondez_pas' => 'Nun responnere a chistu messaggio e-mail, rispunne ncopp’ô forum ô nnerizzo innicato ccà: ', # MODIF
	'forum_page_url' => '(Si ’o messaggio d’’o vuosto è referuto a n’artículo pubbrecato ncopp’â Web, o a na pàggena ca tene cchiú nfromma, putite innicà ccà ’o título d’’a pàggina e ’o nnerizzo URL.)',
	'forum_poste_par' => 'Messaggio mannato ’a @parauteur@ ô funno ’e ll’artículo   « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Chi site?</b> (opzionale)', # MODIF
	'forum_texte' => 'Testo d’’o messaggio:', # MODIF
	'forum_titre' => 'Título:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Abbalurate â scèveta',
	'forum_voir_avant' => 'Vedite ’o messaggio primma d’’o mannà', # MODIF
	'forum_votre_email' => 'Nnerizzo ’e posta elettrònica:', # MODIF
	'forum_votre_nom' => 'Nomme (o scagnanomme/pseudonimo):', # MODIF
	'forum_vous_enregistrer' => 'Pe ppartecipà ô forum, v’avite allegistrà primma. Si l’avite fatto già, scrivite ccà ll’ID d’’a vuosta. Si nun l’avite fatto ancora, v’avite ',
	'forum_vous_inscrire' => 'nscrivere primma.',

	// I
	'icone_suivi_forums' => 'Ammenestrazzione d’’e forum',
	'icone_supprimer_message' => 'Canciella ô messaggio',
	'icone_valider_message' => 'Appruvate ô messaggio',
	'info_activer_forum_public' => '<i>Per attivare i forum pubblici, scegli il tipo
di moderazione predefinito:</i>', # MODIF
	'info_option_email' => 'Quando un visitatore del sito inserisce un nuovo messaggio nel forum
associato a un articolo, gli autori di quest’ultimo possono essere
avvertiti via email. Desideri utilizzare quest’opzione?', # MODIF

	// L
	'lien_reponse_site_reference' => 'Risposta al sito repertoriato:', # MODIF

	// O
	'onglet_messages_internes' => 'Messagge ’e dint’ô sito',
	'onglet_messages_publics' => 'Messagge púbbreche',
	'onglet_messages_vide' => 'Messagge vacante',

	// T
	'titre_forum' => 'Forum',
];
